import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useState } from 'react';
import classnames from "classnames";
import './page-selector.css';

function PageThumbnail(_ref) {
  var _metadata$find, _metadata$find$call;

  var src = _ref.src,
      isActive = _ref.isActive,
      onClick = _ref.onClick,
      metadata = _ref.metadata,
      showMetadata = _ref.showMetadata,
      imageIndex = _ref.imageIndex,
      onMetadataChange = _ref.onMetadataChange;

  var handleChange = function handleChange(e) {
    e.preventDefault();
    var _e$target = e.target,
        name = _e$target.name,
        value = _e$target.value;
    onMetadataChange({
      name: name,
      value: value,
      imageIndex: imageIndex
    });
  };

  var pageNumber = metadata === null || metadata === void 0 ? void 0 : (_metadata$find = metadata.find) === null || _metadata$find === void 0 ? void 0 : (_metadata$find$call = _metadata$find.call(metadata, function (md) {
    return md.key === 'page';
  })) === null || _metadata$find$call === void 0 ? void 0 : _metadata$find$call.value;
  return React.createElement("div", {
    role: "button",
    tabIndex: 0,
    className: classnames('ps-page-thumbnail', {
      'ps-page-thumbnail-is-active': isActive
    }),
    onClick: onClick
  }, React.createElement("div", {
    className: "ps-page-thumbnail-image-wrapper"
  }, React.createElement("img", {
    src: src,
    alt: "",
    className: "ps-page-thumbnail-image"
  }), React.createElement("div", {
    className: "page-number-wrapper"
  }, pageNumber !== undefined && !showMetadata && React.createElement("span", {
    className: "page-number"
  }, pageNumber))), React.createElement("div", {
    className: "ps-page-thumbnail-metadata-wrapper"
  }, metadata.map(function (_ref2) {
    var key = _ref2.key,
        value = _ref2.value;
    return React.createElement(React.Fragment, null, React.createElement("label", {
      for: key
    }, key), React.createElement("input", {
      type: "text",
      value: value,
      name: key,
      onChange: handleChange,
      onClick: function onClick(e) {
        return e.stopPropagation();
      }
    }));
  })));
}

function PageSelector(_ref3) {
  var pages = _ref3.pages,
      onPageClick = _ref3.onPageClick,
      onRecalc = _ref3.onRecalc,
      onSave = _ref3.onSave,
      recalcActive = _ref3.recalcActive,
      saveActive = _ref3.saveActive,
      onMetadataChange = _ref3.onMetadataChange;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      showMetadata = _useState2[0],
      setShowMetadata = _useState2[1];

  return React.createElement("div", {
    className: classnames('page-selector', {
      'page-selector--opened': showMetadata
    })
  }, React.createElement("div", {
    className: "top-buttons"
  }, React.createElement("button", {
    onClick: onRecalc,
    disabled: !recalcActive,
    className: "info"
  }, "Recalc"), React.createElement("button", {
    onClick: onSave,
    disabled: !saveActive,
    className: "success"
  }, "Save"), React.createElement("div", {
    className: "show-metadata-wrapper"
  }, React.createElement("label", {
    className: "switch mr-2"
  }, React.createElement("input", {
    id: "show-metadata",
    type: "checkbox",
    value: showMetadata,
    onChange: function onChange() {
      return setShowMetadata(function (prev) {
        return !prev;
      });
    }
  }), React.createElement("span", {
    className: "slider round"
  })), React.createElement("label", null, "Metadata"))), React.createElement("div", {
    className: "pages"
  }, pages.map(function (page, idx) {
    return React.createElement(PageThumbnail, {
      key: "".concat(page.id),
      src: page.src,
      isActive: page.isActive,
      onClick: function onClick() {
        return onPageClick(idx);
      },
      metadata: page.metadata,
      showMetadata: showMetadata,
      imageIndex: page.id,
      onMetadataChange: onMetadataChange
    });
  })));
}

PageSelector.defaultProps = {
  onPageClick: function onPageClick() {},
  onRecalc: function onRecalc() {},
  onSave: function onSave() {},
  recalcActive: false,
  saveActive: false,
  pageNumber: undefined
};
export default PageSelector;